%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% @brief: Starts The Simulation
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function  Callback_Start_Button( Hobject, callbackData )
    global S;

    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % Stop Timer if it Was Running %
    if(isfield(S,'tm'))
        if(isvalid(S.tm))
            stop(S.tm);
        end
    end

    %%%%%%%%%%%%%%%%%%%%%%%%%%%
    %%%%%%% Parse Data %%%%%%%%
    Px      = str2double(S.EditPx.String);
    Py      = str2double(S.EditPy.String);
    Vx      = str2double(S.EditVx.String);
    Vy      = str2double(S.EditVy.String);
    Dt      = str2double(S.EditDt.String);
    Mass    = str2double(S.EditMass.String);
    Mx      = str2double(S.EditMx.String);
    My      = str2double(S.EditMy.String);
    Rz      = str2double(S.EditRz.String);

    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %%%%%%% Check for Invalid Input %%%%%%%
    Vars = [Px,Py,Vx,Vy,Dt,Mass,Mx,My,Rz];
    if (any(isinf(Vars)) || any(isnan(Vars)))
        msgbox('Invalid Input, please try again','Parsing Error','error');
        return;
    end

    %%%%%%%%%%%%%%%%%%%%
    % Update Variables %
    S.Px    = Px; %  Position X
    S.Py    = Py;   % Position Y
    S.Vx    = Vx;   % Velocity X
    S.Vy    = Vy;   % Velocity Y
    S.Rz    = Rz;   % Earth Radius | Default: [6378 000]
    S.Dt    = Dt;   % Time Step Length in Seconds
    S.Mass  = Mass; % Earth Mass | Default: [5.9736.10^(24)]
    S.Mx    = Mx;   % Earth Position
    S.My    = My;   % Earth Position Y

    %%%%%%%%%%%%%%%%%
    % Update Labels %
    S.EditPx.String     = num2str(Px);
    S.EditPy.String     = num2str(Py);
    S.EditVx.String     = num2str(Vx);
    S.EditVy.String     = num2str(Vy);
    S.EditDt.String     = num2str(Dt);
    S.EditMass.String   = num2str(Mass);
    S.EditMx.String     = num2str(Mx);
    S.EditMy.String     = num2str(My);
    S.EditRz.String     = num2str(Rz);
    

    %%%%%%%%%%%%%%%%%
    % Restart Timer %
    if(isfield(S,'tm'))
        if(isvalid(S.tm))
            S.tm.UserData = S;
            start(S.tm);
        end
    end



end
