%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% iriscores.com 2016/2022
% vojta.ters@iriscores.com
% @brief: Periodic Timer Callback
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function Callback_Timer( mTimer, event )

    global S;
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %%%%%%% Compute Multiple Times per Timer Call %%%%%%%
    for i = 1:S.Nt
     
        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        %%%%%%% Compute Differential Equation %%%%%%%
        switch S.ListBox.Value
            case 1
                % Euler's Method
                 [S.Px,S.Vx,S.Py,S.Vy,Valid] =  EulerCompute(S.Dt,S.Px,S.Vx,S.Py,S.Vy,S.Kappa,S.Mass,S.Rz,S.Mx,S.My);
            case 2
                % Runge-Kutta,Order: 2
                 [S.Px,S.Vx,S.Py,S.Vy,Valid] =  RK2Compute(S.Dt,S.Px,S.Vx,S.Py,S.Vy,S.Kappa,S.Mass,S.Rz,S.Mx,S.My);
            case 3
                % Runge-Kutta,Order: 4
                 [S.Px,S.Vx,S.Py,S.Vy,Valid] =  RK4Compute(S.Dt,S.Px,S.Vx,S.Py,S.Vy,S.Kappa,S.Mass,S.Rz,S.Mx,S.My);
            otherwise
                error('Computing Type Not supported!');
        end
      
        if(~isequal(Valid,1))
            % REACHED SURFACE
            warning('Crashed the Earth Surface!');
            disp('Please Rerun With Different Settings :)');
            stop(S.tm);
            break;
        end
    end
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % Shift Positions to the Right --> and add current set to the beginning %
    S.LastPosX = circshift(S.LastPosX,[0,1]);
    S.LastPosY = circshift(S.LastPosY,[0,1]);
    S.LastVelX = circshift(S.LastVelX,[0,1]);
    S.LastVelY = circshift(S.LastVelY,[0,1]);
    S.LastPosX(1) =  S.Px;
    S.LastPosY(1) =  S.Py;
    S.LastVelX(1) =  S.Vx;
    S.LastVelY(1) =  S.Vy;

    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % Set Main Axes to be Focused %
    axes(S.AxPos);
    
    delete(S.PPos);
    S.PPos = plot(S.LastPosX,S.LastPosY,'.','MarkerSize',S.MSize,'color',S.Cls(S.Cl_Blue,:));
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % Rescale Plot Limits if Necessary %
    if((S.Px < S.MiX) || (S.Py < S.MiY) || (S.Px > S.MaX) || (S.Py > S.MaY))
        if (S.Px < S.MiX)
          S.MiX = S.Px;
        end
        if (S.Py < S.MiY)
          S.MiY = S.Py;
        end
        if (S.Px > S.MaX)
          S.MaX = S.Px;
        end
        if (S.Py > S.MaY)
          S.MaY = S.Py;
        end

        %%%%%%%%%%%%%%%%%
        % Update Limits %
        xlim([S.MiX,S.MaX]);
        ylim([S.MiY,S.MaY]);
        axis equal;

    end

    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % Set Velocity Axes to be Focused % 
    axes(S.AxVel);

    %%%%%%%%%%%%%%%%%%%%%%%%
    % Delete Previous Data %
    delete(S.PVelX);
    delete(S.PVelY);
    delete(S.PVelT);

    %%%%%%%%%%%%%%%%%%%%%%%
    % Draw New Velocities %
    S.PVelX = plot(S.LastVelX,'color',S.VelXCl);
    S.PVelY = plot(S.LastVelY,'color',S.VelYCl);
    S.PVelT = plot(sqrt(S.LastVelX.^2 + S.LastVelY.^2),'color',S.VelACl);
    legend('X - Speed','Y - Speed','Abs Speed');
    
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % Update EditBoxes with new Values %
    S.EditPx.String = num2str(S.Px);
    S.EditPy.String = num2str(S.Py);
    S.EditVx.String = num2str(S.Vx);
    S.EditVy.String = num2str(S.Vy);


end

